==> devspaces-dashboard-rhel8-container-3.9-25.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-frontend/src/pages/WorkspaceDetails/DevworkspaceEditorTab/index.tsx <==
/*
 * Copyright (c) 2018-2023 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import React from 'react';
import { TextContent } from '@patternfly/react-core';
import DevworkspaceEditor from '../../../components/WorkspaceEditor';
import EditorTools from '../../../components/EditorTools';
import { Workspace } from '../../../services/workspace-adapter';

import styles from './index.module.css';

export type Props = {
  workspace: Workspace;
  isActive: boolean;
};

export type State = {
  isExpanded: boolean;
  copied?: boolean;
};

export class DevworkspaceEditorTab extends React.PureComponent<Props, State> {
  constructor(props: Props) {
    super(props);

    this.state = {
      isExpanded: false,
    };
  }

  public render(): React.ReactElement {
    const { isExpanded } = this.state;
    const { workspace } = this.props;
    const editorTabStyle = isExpanded ? styles.editorTabExpanded : styles.editorTab;

    return (
      <>
        <br />
        <TextContent className={editorTabStyle}>
          <EditorTools
            devfileOrDevWorkspace={workspace.ref}
            handleExpand={isExpanded => {
              this.setState({ isExpanded });
            }}
          />
          <DevworkspaceEditor workspace={workspace.ref} isActive={this.props.isActive} />
        </TextContent>
      </>
    );
  }
}

export default DevworkspaceEditorTab;

==> devspaces-dashboard-rhel8-container-3.10-57.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-frontend/src/pages/WorkspaceDetails/DevworkspaceEditorTab/index.tsx <==
/*
 * Copyright (c) 2018-2023 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import { TextContent } from '@patternfly/react-core';
import { dump } from 'js-yaml';
import React from 'react';

import DevfileViewer from '@/components/DevfileViewer';
import EditorTools from '@/components/EditorTools';
import styles from '@/pages/WorkspaceDetails/DevworkspaceEditorTab/index.module.css';
import { Workspace } from '@/services/workspace-adapter';

export type Props = {
  workspace: Workspace;
  isActive: boolean;
};

export type State = {
  isExpanded: boolean;
  copied?: boolean;
};

export class DevworkspaceEditorTab extends React.PureComponent<Props, State> {
  constructor(props: Props) {
    super(props);

    this.state = {
      isExpanded: false,
    };
  }

  public render(): React.ReactElement {
    const { isExpanded } = this.state;
    const { workspace } = this.props;
    const editorTabStyle = isExpanded ? styles.editorTabExpanded : styles.editorTab;
    const devWorkspaceStr = dump(workspace.ref);

    return (
      <>
        <br />
        <TextContent className={editorTabStyle}>
          <EditorTools
            devfileOrDevWorkspace={workspace.ref}
            handleExpand={isExpanded => {
              this.setState({ isExpanded });
            }}
          />
          <DevfileViewer
            isActive={this.props.isActive}
            isExpanded={isExpanded}
            value={devWorkspaceStr}
            id="devWorkspaceViewerId"
          />
        </TextContent>
      </>
    );
  }
}

export default DevworkspaceEditorTab;
